Index: main/waeup.kofa/branches/henrik-regista/CHANGES.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/CHANGES.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/CHANGES.txt	(revision 11952)
@@ -6,5 +6,5 @@
 
 * Enucleation: Keep only the portal's framework.
-  Remove university, students, applicants, hostels and accesscodes modules.
+  Remove institution, students, applicants, hostels and accesscodes modules.
 
 0.1 (never released)
Index: main/waeup.kofa/branches/henrik-regista/README.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/README.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/README.txt	(revision 11952)
@@ -1,12 +1,11 @@
 What is WAeUP.Ikoba ?
-********************
+*********************
 
-Ikoba, which means 'entrance' or 'portal' in Hausa language,
-is a multifunctional Student Management System and a
+Ikoba, which means 'bucket' in Bini language,
+is a multifunctional Application and Registration
 Web Portal to provide transparent and comprehensive information about
-study progress. The system controls all kinds of application and student
-registration processes at large schools and universities in Nigeria.
+application and registration progress.
 
-Ikoba is the flagship of the West African eUniversity Project (WAeUP).
+Ikoba is the second flagships of the West African eInstitution Project (WAeUP).
 See http://www.waeup.org to learn more about WAeUP.
 
Index: main/waeup.kofa/branches/henrik-regista/buildout.cfg
===================================================================
--- main/waeup.kofa/branches/henrik-regista/buildout.cfg	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/buildout.cfg	(revision 11952)
@@ -197,5 +197,5 @@
 eggs = z3c.coverage
 scripts = coveragereport
-arguments = ('${buildout:parts-directory}/coverage-detect/working-directory/coverage', '${buildout:directory}/coverage-report')
+arguments = ('${buildout:parts-directory}/coverage-detect/coverage', '${buildout:directory}/coverage-report')
 
 [lxml]
Index: main/waeup.kofa/branches/henrik-regista/docs/INSTALL.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/INSTALL.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/INSTALL.txt	(revision 11952)
@@ -3,5 +3,5 @@
 
 These are generic installation instructions for the WAeUP_ ``Ikoba``
-student information portal and customized versions thereof.
+application and registration portal and customized versions thereof.
 
 For specific aspects of this package please refer to the local README
@@ -263,7 +263,7 @@
 If you are connected and logged in,
 you should be able to add the grok-based applications
-(such as ``University``) from the menu.
-
-Add an instance of ``University`` and click on the link next to the
+(such as ``Institution``) from the menu.
+
+Add an instance of ``Institution`` and click on the link next to the
 then visible entry in the list of installed applications.
 
Index: main/waeup.kofa/branches/henrik-regista/docs/make.bat
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/make.bat	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/make.bat	(revision 11952)
@@ -75,7 +75,7 @@
 	echo.Build finished; now you can run "qcollectiongenerator" with the ^
 .qhcp project file in %BUILDDIR%/qthelp, like this:
-	echo.^> qcollectiongenerator %BUILDDIR%\qthelp\WAeUPStudentInformationandRegistrationPortalKOFA.qhcp
+	echo.^> qcollectiongenerator %BUILDDIR%\qthelp\WAeUPIkoba.qhcp
 	echo.To view the help file:
-	echo.^> assistant -collectionFile %BUILDDIR%\qthelp\WAeUPStudentInformationandRegistrationPortalKOFA.ghc
+	echo.^> assistant -collectionFile %BUILDDIR%\qthelp\WAeUPIkoba.ghc
 	goto end
 )
Index: main/waeup.kofa/branches/henrik-regista/docs/source/conf.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/source/conf.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/source/conf.py	(revision 11952)
@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 #
-# WAeUP Student Information and Registration Portal (Ikoba) documentation build configuration file, created by
+# WAeUP Application and Registration Portal (Ikoba) documentation build configuration file, created by
 # sphinx-quickstart on Thu Jul 29 10:41:59 2010.
 #
@@ -174,5 +174,5 @@
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = 'WAeUPStudentInformationandRegistrationPortalIkobadoc'
+htmlhelp_basename = 'WAeUPIkoba'
 
 
@@ -188,5 +188,5 @@
 # (source start file, target name, title, author, documentclass [howto/manual]).
 latex_documents = [
-  ('index', 'WAeUPStudentInformationandRegistrationPortalIkoba.tex', u'WAeUP Student Information and Registration Portal (Ikoba) Documentation',
+  ('index', 'WAeUPIkoba.tex', u'WAeUP Application and Registration Portal (Ikoba) Documentation',
    u'WAeUP Team', 'manual'),
 ]
Index: main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/api_app.rst
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/api_app.rst	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/api_app.rst	(revision 11952)
@@ -1,3 +1,3 @@
-`app` -- University Root (Site) Module
+`app` -- Institution Root (Site) Module
 **************************************
 
Index: main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/api_interfaces.rst
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/api_interfaces.rst	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/api_interfaces.rst	(revision 11952)
@@ -6,5 +6,5 @@
    :undoc-members:
 
-.. autointerface:: waeup.ikoba.interfaces.IUniversity
+.. autointerface:: waeup.ikoba.interfaces.IInstitution
    :members:
    :undoc-members:
Index: main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/index.rst
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/index.rst	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/source/developerdocs/api/index.rst	(revision 11952)
@@ -13,7 +13,5 @@
    :maxdepth: 1
 
-   api_accesscodes
    api_app
-   api_applicants
    api_async
    api_authentication
@@ -24,5 +22,4 @@
    api_datacenter
    api_fees
-   api_hostels
    api_image
    api_imagestorage
@@ -41,6 +38,5 @@
    api_sourcefactory
    api_startup
-   api_students
-   api_university
+   api_institution
    api_userscontainer
    api_utils
Index: main/waeup.kofa/branches/henrik-regista/docs/source/glossary.rst
===================================================================
--- main/waeup.kofa/branches/henrik-regista/docs/source/glossary.rst	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/docs/source/glossary.rst	(revision 11952)
@@ -10,5 +10,5 @@
 
    WAeUP
-     West African e-University Project.
+     West African e-Institution Project.
 
    waeup.ikoba
Index: main/waeup.kofa/branches/henrik-regista/setup.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/setup.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/setup.py	(revision 11952)
@@ -87,8 +87,8 @@
 setup(name = 'waeup.ikoba',
       version = version,
-      description = "A student online information and  registration portal",
+      description = "An online application and registration portal",
       long_description = long_description,
 
-      keywords = "portal waeup ikoba student university registration grok zope",
+      keywords = "portal waeup ikoba institution application registration grok zope",
       # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
       classifiers = [
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.txt	(revision 11952)
@@ -7,25 +7,25 @@
 .. module:: waeup.ikoba.app
 
-.. class:: University
+.. class:: Institution
 
   The main Ikoba application object is given with
-  :class:`University`. It provides the main containers as faculties,
+  :class:`Institution`. It provides the main containers as faculties,
   hostels, etc.
 
   .. attribute:: name
 
-     A string. The name of a university.
+     A string. The name of a institution.
 
   .. attribute:: faculties
 
      An arbitrary object containing "faculties". In the case of
-     `University` it is a container of type
+     `Institution` it is a container of type
      `waeup.ikoba.interfaces.IFacultiesContainer`.
 
 
-Creating `University` instances
+Creating `Institution` instances
 ===============================
 
-As :class:`University` instances make use of the Zope Component
+As :class:`Institution` instances make use of the Zope Component
 Architecture (ZCA), we have to setup the basic component registries,
 before we can create instances. We do this by simply grokking the
@@ -34,18 +34,18 @@
 registries (this is done by the testlayer automatically).
 
-Now we can import the :class:`University` class and create an
+Now we can import the :class:`Institution` class and create an
 instance:
 
-    >>> from waeup.ikoba.app import University
-    >>> myuniversity = University()
-    >>> myuniversity
-    <waeup.ikoba.app.University object at 0x...>
+    >>> from waeup.ikoba.app import Institution
+    >>> myinstitution = Institution()
+    >>> myinstitution
+    <waeup.ikoba.app.Institution object at 0x...>
 
-Instances of `University` comply with the interface
-`waeup.ikoba.interfaces.IUniversity`:
+Instances of `Institution` comply with the interface
+`waeup.ikoba.interfaces.IInstitution`:
 
     >>> from zope.interface.verify import verifyClass
-    >>> from waeup.ikoba.interfaces import IUniversity
-    >>> verifyClass(IUniversity, University)
+    >>> from waeup.ikoba.interfaces import IInstitution
+    >>> verifyClass(IInstitution, Institution)
     True
 
@@ -53,16 +53,16 @@
 interface:
 
-    >>> from waeup.ikoba.app import University
-    >>> myuniversity = University()
-    >>> myuniversity['configuration'].name
-    u'Sample University'
+    >>> from waeup.ikoba.app import Institution
+    >>> myinstitution = Institution()
+    >>> myinstitution['configuration'].name
+    u'Sample Institution'
 
-  >>> myuniversity['users']
+  >>> myinstitution['users']
   <waeup.ikoba.userscontainer.UsersContainer object at 0x...>
 
-  >>> myuniversity['datacenter']
+  >>> myinstitution['datacenter']
   <waeup.ikoba.datacenter.DataCenter object at 0x...>
 
-  >>> myuniversity['configuration']
+  >>> myinstitution['configuration']
   <waeup.ikoba.configuration.ConfigurationContainer object at 0x...>
 
@@ -103,9 +103,9 @@
 and setup a new Ikoba instance, we will get a message:
 
-   >>> from waeup.ikoba.app import University
-   >>> site = University()
+   >>> from waeup.ikoba.app import Institution
+   >>> site = Institution()
    Setup was called for
-   <waeup.ikoba.app.University object at 0x...>
+   <waeup.ikoba.app.Institution object at 0x...>
 
-Apparently the plugin can do with the University object whatever it
+Apparently the plugin can do with the Institution object whatever it
 likes. That's what plugins are for.
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/authentication.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/authentication.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/authentication.txt	(revision 11952)
@@ -11,7 +11,7 @@
 
   >>> from zope.component.hooks import setSite # only needed in tests
-  >>> from waeup.ikoba.app import University
+  >>> from waeup.ikoba.app import Institution
   >>> root = getRootFolder()
-  >>> u = University()
+  >>> u = Institution()
   >>> root['app'] = u
   >>> setSite(root['app'])                     # only needed in tests
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/batchprocessing.txt	(revision 11952)
@@ -21,6 +21,6 @@
 Create a site:
 
-    >>> from waeup.ikoba.app import University
-    >>> getRootFolder()['app'] = University()
+    >>> from waeup.ikoba.app import Institution
+    >>> getRootFolder()['app'] = Institution()
     >>> from zope.component.hooks import setSite
     >>> setSite(getRootFolder()['app'])
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.txt	(revision 11952)
@@ -9,9 +9,9 @@
 ===============================
 
-We create a university to check the breadcrumb functionality.
-
-    >>> from waeup.ikoba.app import University
+We create a institution to check the breadcrumb functionality.
+
+    >>> from waeup.ikoba.app import Institution
     >>> root = getRootFolder()
-    >>> root['app'] = University()
+    >>> root['app'] = Institution()
     >>> app = root['app']
 
@@ -25,5 +25,5 @@
     >>> blist1 = getBreadcrumbList(app, 'index')
     >>> blist1
-    [<waeup.ikoba.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>]
+    [<waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>]
 
 A slightly more extensive list for the datacenter:
@@ -32,9 +32,9 @@
     >>> from pprint import pprint
     >>> pprint(blist2)
-    [<waeup.ikoba.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>,
+    [<waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>,
      <waeup.ikoba.browser.breadcrumbs.AdministrationBreadcrumb object at 0x...>,
      <waeup.ikoba.browser.breadcrumbs.DataCenterBreadcrumb object at 0x...>]
 
-We get a breadcrumb for university, administration area and data
+We get a breadcrumb for institution, administration area and data
 center in that order.
 
@@ -47,11 +47,11 @@
 
      >>> pprint([(x.context, x.viewname) for x in blist2])
-     [(<waeup.ikoba.app.University object at 0x...>, 'index'),
-      (<waeup.ikoba.app.University object at 0x...>, 'administration'),
+     [(<waeup.ikoba.app.Institution object at 0x...>, 'index'),
+      (<waeup.ikoba.app.Institution object at 0x...>, 'administration'),
       (<waeup.ikoba.datacenter.DataCenter object at 0x...>, 'index')]
 
 The administration area breadcrumb might be a surprise, as there is no
 equivalent object in the ZODB. In fact the administration area is only
-a certain view (the 'administration' view) on the university object.
+a certain view (the 'administration' view) on the institution object.
 
 We will show below, how you can define breadcrumbs this way.
@@ -62,5 +62,5 @@
 
 This way we can make sure, that there are different breadcrumb lists
-generated for instance for the administration view of University
+generated for instance for the administration view of Institution
 instances and the index view. While the first should look something
 like::
@@ -118,5 +118,5 @@
 
     >>> pprint(mybccontainer.getList())
-    [<...breadcrumbs.UniversityBreadcrumb object at 0x...>,
+    [<...breadcrumbs.InstitutionBreadcrumb object at 0x...>,
      <...breadcrumbs.AdministrationBreadcrumb object at 0x...>,
      <...breadcrumbs.UsersContainerBreadcrumb object at 0x...>]
@@ -128,5 +128,5 @@
 
 Now we can get breadcrumbs for contexts and view names. For example a
-breadcrumb for the 'index' view of our University object:
+breadcrumb for the 'index' view of our Institution object:
 
     >>> from zope.component import getAdapter
@@ -134,5 +134,5 @@
     >>> b1 = getAdapter(app, IBreadcrumb, 'index')
     >>> b1
-    <waeup.ikoba.browser.breadcrumbs.UniversityBreadcrumb object at 0x...>
+    <waeup.ikoba.browser.breadcrumbs.InstitutionBreadcrumb object at 0x...>
 
 Breadcrumb objects provide a title:
@@ -168,7 +168,7 @@
 
     >>> b2.parent
-    (<waeup.ikoba.app.University object at 0x...>, 'administration')
-
-This result denotes a new context object (the University instance we
+    (<waeup.ikoba.app.Institution object at 0x...>, 'administration')
+
+This result denotes a new context object (the Institution instance we
 created above) and a view name ('administration').
 
@@ -188,5 +188,5 @@
 As you can see, we get an AdministrationBreadcrumb, although the
 context object, for which the breadcrumb was created is also the
-University instance as above:
+Institution instance as above:
 
     >>> b3.context is b1.context
@@ -197,5 +197,5 @@
     >>> context, viewname = b3.parent
     >>> context, viewname
-    (<waeup.ikoba.app.University object at 0x...>, 'index')
+    (<waeup.ikoba.app.Institution object at 0x...>, 'index')
 
 We create last breadcrumb:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/browser.txt	(revision 11952)
@@ -4,10 +4,10 @@
 Here we visit all parts of a Ikoba portal using a browser.
 
-University
+Institution
 ==========
 
 We can watch universities in the browser.
 
-We create an university object and put into the ZODB root::
+We create an institution object and put into the ZODB root::
 
   >>> root = getRootFolder()
@@ -15,12 +15,12 @@
   []
 
-  >>> from waeup.ikoba.app import University
-  >>> u = University()
-  >>> root['myuniversity'] = u
+  >>> from waeup.ikoba.app import Institution
+  >>> u = Institution()
+  >>> root['myinstitution'] = u
   >>> list(root)
-  [u'myuniversity']
+  [u'myinstitution']
 
   >>> from zope.component.hooks import setSite
-  >>> setSite(root['myuniversity'])
+  >>> setSite(root['myinstitution'])
 
 To make sure, we can 'watch' pages, we first have to initialize out
@@ -30,7 +30,7 @@
   >>> browser = Browser()
 
-Let's get the default view of a university::
-
-  >>> browser.open('http://localhost/myuniversity')
+Let's get the default view of a institution::
+
+  >>> browser.open('http://localhost/myinstitution')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -55,5 +55,5 @@
 The contact form for anonymous users is called 'Enquiries'::
 
-  >>> browser.open('http://localhost/myuniversity')
+  >>> browser.open('http://localhost/myinstitution')
   >>> browser.getLink('Enquiries').click()
   >>> browser.getControl('Send').click()
@@ -74,7 +74,7 @@
 Registered users with an email address can request a password change:
 
-  >>> root['myuniversity']['users'].addUser('forgetful', 'secret',title='Bob Forgetful',
+  >>> root['myinstitution']['users'].addUser('forgetful', 'secret',title='Bob Forgetful',
   ...                               description='A forgetful user', email='aa@aa.ng')
-  >>> browser.open('http://localhost/myuniversity/changepw')
+  >>> browser.open('http://localhost/myinstitution/changepw')
   >>> browser.getControl(name="form.identifier").value = 'forgetful'
   >>> browser.getControl(name="form.email").value = 'aa@aa.ng'
@@ -91,13 +91,13 @@
 We can then get an edit view of the configuration container::
 
-  >>> browser.open('http://localhost/myuniversity/configuration')
-  >>> print browser.contents
-  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
-  ...<form action="http://localhost/myuniversity/configuration/@@index"
-  ...
-
-The edit form contains the default value for the university name::
-
-  >>> 'Sample University' in browser.contents
+  >>> browser.open('http://localhost/myinstitution/configuration')
+  >>> print browser.contents
+  <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
+  ...<form action="http://localhost/myinstitution/configuration/@@index"
+  ...
+
+The edit form contains the default value for the institution name::
+
+  >>> 'Sample Institution' in browser.contents
   True
 
@@ -110,5 +110,5 @@
   ...
 
-  >>> browser.open('http://localhost/myuniversity/configuration')
+  >>> browser.open('http://localhost/myinstitution/configuration')
   >>> browser.getControl("Update plugins").click()
   >>> print browser.contents
@@ -120,5 +120,5 @@
 and is properly rendered on the frontpage of the portal:
 
-  >>> browser.open('http://localhost/myuniversity')
+  >>> browser.open('http://localhost/myinstitution')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -134,5 +134,5 @@
 If we change to German so that the German part of frontpage.rst is rendered:
 
-  >>> browser.open('http://localhost/myuniversity//@@change_language?lang=de')
+  >>> browser.open('http://localhost/myinstitution//@@change_language?lang=de')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -147,5 +147,5 @@
 Switch back to English:
 
-  >>> browser.open('http://localhost/myuniversity//@@change_language?lang=en')
+  >>> browser.open('http://localhost/myinstitution//@@change_language?lang=en')
 
 
@@ -153,5 +153,5 @@
 ============
 
-  >>> browser.open('http://localhost/myuniversity')
+  >>> browser.open('http://localhost/myinstitution')
   >>> browser.getLink('Portal Users').click()
   >>> print browser.contents
@@ -187,10 +187,10 @@
 manually by setting the roles attribute:
 
-  >>> print root['myuniversity']['users']['bob'].roles
+  >>> print root['myinstitution']['users']['bob'].roles
   []
-  >>> root['myuniversity']['users']['bob'].roles = ['waeup.UsersManager']
-  >>> print root['myuniversity']['users']['bob'].roles
+  >>> root['myinstitution']['users']['bob'].roles = ['waeup.UsersManager']
+  >>> print root['myinstitution']['users']['bob'].roles
   ['waeup.UsersManager']
-  >>> browser.open('http://localhost/myuniversity/users')
+  >>> browser.open('http://localhost/myinstitution/users')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -200,5 +200,5 @@
 Users can't be added twice:
 
-  >>> browser.open('http://localhost/myuniversity/users/add')
+  >>> browser.open('http://localhost/myinstitution/users/add')
   >>> browser.getControl(name="form.name").value = 'bob'
   >>> browser.getControl(name="form.title").value = 'Bob The User'
@@ -215,5 +215,5 @@
 Users can be deleted:
 
-  >>> browser.open('http://localhost/myuniversity/users')
+  >>> browser.open('http://localhost/myinstitution/users')
   >>> browser.getControl("Remove", index=0).click()
   >>> 'User account bob successfully deleted' in browser.contents
@@ -227,5 +227,5 @@
 Let's enter the contact form::
 
-  >>> browser.open('http://localhost/myuniversity/contactadmin')
+  >>> browser.open('http://localhost/myinstitution/contactadmin')
   >>> print browser.contents
   <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"...
@@ -236,5 +236,5 @@
 contact@waeup.org)::
 
-  >>> browser.open('http://localhost/myuniversity/contactadmin')
+  >>> browser.open('http://localhost/myinstitution/contactadmin')
   >>> browser.getControl(name='form.body').value = "test message"
   >>> browser.getControl('Send').click()
@@ -253,5 +253,5 @@
 The data center helps us uploading files for later import or similar.
 
-  >>> browser.open('http://localhost/myuniversity')
+  >>> browser.open('http://localhost/myinstitution')
   >>> browser.getLink('Data Center').click()
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/captcha.py	(revision 11952)
@@ -32,5 +32,5 @@
     ICaptchaRequest, ICaptchaResponse, ICaptcha, ICaptchaConfig,
     ICaptchaManager)
-from waeup.ikoba.interfaces import IUniversity
+from waeup.ikoba.interfaces import IInstitution
 
 #
@@ -322,5 +322,5 @@
     # A test page to see a captcha in action
     grok.name('captcha')
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.require('waeup.Public')
     title = 'Captcha Test'
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/exceptions.py	(revision 11952)
@@ -64,5 +64,5 @@
     """A page rendered when an object cannot be found.
 
-    XXX: This page won't work for objects above a w.k.University.
+    XXX: This page won't work for objects above a w.k.Institution.
     """
     grok.context(INotFound)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/interfaces.py	(revision 11952)
@@ -21,5 +21,5 @@
 from zope.interface import Interface, Attribute
 from waeup.ikoba.interfaces import (
-    IIkobaObject, IUniversity, IUsersContainer, IDataCenter, validate_email)
+    IIkobaObject, IInstitution, IUsersContainer, IDataCenter, validate_email)
 from waeup.ikoba.interfaces import MessageFactory as _
 
@@ -161,5 +161,5 @@
 
         If no `headerline` is given, a default will be rendered (name
-        of university).
+        of institution).
 
         If no `title` is given, nothing will be rendered.
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/layout.py	(revision 11952)
@@ -220,5 +220,5 @@
     #: An instance of the default theme to use for the site layout
     stafftemp = grok.PageTemplateFile('templates/staffsitelayout.pt')
-    studenttemp = grok.PageTemplateFile('templates/studentsitelayout.pt')
+    customertemp = grok.PageTemplateFile('templates/customersitelayout.pt')
 
     @property
@@ -227,5 +227,5 @@
 
     def getAppTitle(self):
-        return getattr(grok.getSite()['configuration'], 'name', u'Sample University')
+        return getattr(grok.getSite()['configuration'], 'name', u'Sample Institution')
 
     def getAppAcronym(self):
@@ -287,4 +287,4 @@
     def render(self):
         if self.isCustomer() or not self.isAuthenticated():
-            return self.studenttemp.render(self)
+            return self.customertemp.render(self)
         return self.stafftemp.render(self)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pdf.py	(revision 11952)
@@ -710,5 +710,5 @@
             doc, 'ikoba_headtitle', getattr(
                 site_config, 'name',
-                u'Sample University'))
+                u'Sample Institution'))
         canvas.setFont("Helvetica-Bold", 18)
         if self.header_logo_left_path is not None:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/customersitelayout.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/customersitelayout.pt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/customersitelayout.pt	(revision 11952)
@@ -0,0 +1,107 @@
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" i18n:domain="waeup.ikoba">
+  <head>
+    <title i18n:translate="">
+      WAeUP.Ikoba - Application and Registration System
+    </title>
+    <!--base href="http://localhost:8080/app/@@page"
+     tal:attributes="href python: view.url(layout.site)" / -->
+    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
+    <meta name="robots" content="index, follow" />
+    <link rel="stylesheet" media="only screen and (max-device-width: 480px)"
+        tal:attributes="href python: view.url(layout.site, '@@/waeup.ikoba.browser/mobile.css')"
+        type="text/css" />
+    <link rel="alternate" type="application/rss+xml" title="RSS"
+        href="http://www.example.net/feed.rss"
+        tal:attributes="title string:RSS feed of ${layout/getAppTitle};
+            href python: view.url(layout.site, 'feed.rss')" />
+  </head>
+
+  <!-- Diazo element-->
+  <body class="ikoba-body">
+
+    <!-- Diazo element-->
+    <a class="ikoba-brand-link" href="#"
+        tal:attributes="href python: view.url(layout.site)"
+        tal:content="layout/getAppAcronym">ACRONYM</a>
+    <!-- /Diazo element-->
+
+    <!-- Diazo element-->
+    <ul class="nav ikoba-navbar-left">
+        <tal:primary_nav content="structure provider:primary_nav" />
+    </ul>
+    <!-- /Diazo element-->
+
+    <!-- Diazo element-->
+    <ul class="nav secondary-nav ikoba-navbar-right">
+      <li tal:condition="not: layout/isAuthenticated">
+      <a href="#" i18n:translate=""
+         tal:attributes="href python: view.url(layout.site, 'login')">
+          Login
+      </a>
+      </li>
+      <li tal:condition="layout/isAuthenticated">
+      <a href="#" i18n:translate=""
+         tal:attributes="href python: view.url(layout.site, '@@contactadmin')">
+          Contact
+      </a>
+      </li>
+      <li tal:condition="layout/isAuthenticated">
+      <a href="#" i18n:translate=""
+         tal:attributes="href python: view.url(context, '@@logout')">
+         Logout
+      </a>
+      </li>
+    </ul>
+    <!-- Diazo element-->
+
+    <span tal:define="langs provider:languages"
+          tal:condition="langs"
+          class="language">
+      <tal:languages tal:content="structure langs" /> |
+    </span>
+
+    <!-- Diazo element-->
+    <ul class="breadcrumb" tal:condition="layout/isAuthenticated">
+      <tal:breadcrumbs
+            tal:condition="python: layout.isAuthenticated()"
+            tal:content="structure provider:breadcrumbs" />
+    </ul>
+    <!-- /Diazo element-->
+
+    <!-- Diazo element-->
+    <div class="ikoba-content">
+      <div class="actionbar" tal:condition="provider:actionbar">
+        <tal:actionbar content="structure provider:actionbar" />&nbsp;
+      </div>
+      <div tal:define="message context/@@messages"
+           tal:condition="python: len(message)>11">
+        <div tal:content="structure message">
+        </div>
+      </div>
+      <div class="alert alert-danger"
+        tal:define="status view/status|nothing"
+        tal:condition="status">
+        <span tal:content="view/status">
+          FORM STATUS SUMMARY
+        </span>:
+        <ul id="alert-error" tal:condition="view/errors">
+          <li tal:repeat="error view/error_views">
+             <span tal:replace="structure error">Error Type</span>
+          </li>
+        </ul>
+      </div>
+      <h1 class="ikoba-content-label"
+          tal:condition="view/label|nothing"
+          tal:content="structure view/label">Label</h1>
+      <div tal:content="structure view/content">
+        THE CONTENT
+      </div>
+      <br />
+    </div>
+    <!-- /Diazo element-->
+
+  </body>
+  <!-- /Diazo element-->
+
+</html>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/datacenterexportpage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/datacenterexportpage.pt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/datacenterexportpage.pt	(revision 11952)
@@ -1,4 +1,4 @@
 <p i18n:translate="">
-  Here you can create CSV files from parts of portal data except student data.
+  Here you can create CSV files from parts of portal data.
   Please pick the type of objects you want to export from the
   selection below. The file will be generated and then be
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionpage.pt	(revision 11952)
@@ -0,0 +1,1 @@
+<span tal:replace="structure view/frontpage">Frontpage</span>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt	(revision 11952)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/institutionrss20feed.pt	(revision 11952)
@@ -0,0 +1,59 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<rss version="2.0"
+     xmlns:tal="http://xml.zope.org/namespaces/tal"
+     xmlns:atom="http://www.w3.org/2005/Atom">
+  <channel>
+    <title>
+      <tal:block tal:content="view/title"/>
+      <tal:block
+	  tal:define="title view/contexttitle"
+	  tal:condition="title"> - <tal:block content="title"/>
+      </tal:block>
+    </title>
+    <link
+	tal:content="view/link"></link>
+    <description
+	tal:content="view/description"></description>
+    <language
+	tal:condition="view/language"
+	tal:content="view/language"></language>
+    <pubDate
+	tal:condition="view/date"
+	tal:content="view/date"></pubDate>
+    <lastBuildDate
+	tal:condition="view/buildDate"
+	tal:content="view/buildDate"></lastBuildDate>
+    <managingEditor
+	tal:condition="view/editor"
+	tal:content="view/editor"></managingEditor>
+    <webMaster
+	tal:condition="view/webmaster"
+	tal:content="view/webmaster"></webMaster>
+    <atom:link
+	tal:attributes="href string:${view/link}@@feeds/${view/name}"
+	rel="self" type="application/rss+xml" />
+    <item
+	tal:repeat="item view/entries">
+      <title
+	  tal:content="item/title"></title>
+      <description
+	  tal:content="item/description"></description>
+      <guid
+	  tal:content="item/guid"
+	  tal:define="isPermaLink item/isPermaLink|nothing"
+	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
+      <link
+	  tal:condition="item/link|nothing"
+	  tal:content="item/link"></link>
+      <author
+	  tal:condition="item/author|nothing"
+	  tal:content="item/author"></author>
+      <category
+	  tal:condition="item/category|nothing"
+	  tal:content="item/category"></category>
+      <pubDate
+	  tal:condition="item/pubDate|nothing"
+	  tal:content="item/pubDate"></pubDate>
+    </item>
+  </channel>
+</rss>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/loginpage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/loginpage.pt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/loginpage.pt	(revision 11952)
@@ -22,13 +22,13 @@
   </p>
   <p i18n:translate="login_trouble2" tal:condition="python:False">
-    You don't have an account because you are a fresh student, or your student record has just been created?
-    Acquire a Password Activation Code (PWD) and inititialize your student account
+    You don't have an account because you are a new customer, or your customer record has just been created?
+    Acquire a Password Activation Code (PWD) and inititialize your customer account
     <strong><a href ="setpassword"> here</a></strong>.
   </p>
   <p i18n:translate="login_trouble4">
-    You don't have an account because you are a fresh student, or your student record has just been created?
-    Inititialize your student account <strong><a href="requestpw"> here</a></strong>.
+    You don't have an account because you are a new customer, or your customer record has just been created?
+    Inititialize your customer account <strong><a href="requestpw"> here</a></strong>.
   </p>
-  <p i18n:translate="login_trouble3"> Or simply forgot your student id, application id or password? Then request a new password
+  <p i18n:translate="login_trouble3"> Or simply forgot your customer id password? Then request a new password
     <strong><a href="changepw"> here</a></strong>.
   </p>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/staffsitelayout.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/staffsitelayout.pt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/staffsitelayout.pt	(revision 11952)
@@ -5,5 +5,5 @@
     <!-- Diazo element-->
     <title i18n:translate="">
-      WAeUP.Ikoba - Student Management System
+      WAeUP.Ikoba - Application and Registration System
     </title>  
     <!-- /Diazo element-->
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/studentsitelayout.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/studentsitelayout.pt	(revision 11951)
+++ 	(revision )
@@ -1,107 +1,0 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" i18n:domain="waeup.ikoba">
-  <head>
-    <title i18n:translate="">
-      WAeUP.Ikoba - Student Management System
-    </title>
-    <!--base href="http://localhost:8080/app/@@page"
-     tal:attributes="href python: view.url(layout.site)" / -->
-    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
-    <meta name="robots" content="index, follow" />
-    <link rel="stylesheet" media="only screen and (max-device-width: 480px)"
-        tal:attributes="href python: view.url(layout.site, '@@/waeup.ikoba.browser/mobile.css')"
-        type="text/css" />
-    <link rel="alternate" type="application/rss+xml" title="RSS"
-        href="http://www.example.net/feed.rss"
-        tal:attributes="title string:RSS feed of ${layout/getAppTitle};
-            href python: view.url(layout.site, 'feed.rss')" />
-  </head>
-
-  <!-- Diazo element-->
-  <body class="ikoba-body">
-
-    <!-- Diazo element-->
-    <a class="ikoba-brand-link" href="#"
-        tal:attributes="href python: view.url(layout.site)"
-        tal:content="layout/getAppAcronym">ACRONYM</a>
-    <!-- /Diazo element-->
-
-    <!-- Diazo element-->
-    <ul class="nav ikoba-navbar-left">
-        <tal:primary_nav content="structure provider:primary_nav" />
-    </ul>
-    <!-- /Diazo element-->
-
-    <!-- Diazo element-->
-    <ul class="nav secondary-nav ikoba-navbar-right">
-      <li tal:condition="not: layout/isAuthenticated">
-      <a href="#" i18n:translate=""
-         tal:attributes="href python: view.url(layout.site, 'login')">
-          Login
-      </a>
-      </li>
-      <li tal:condition="layout/isAuthenticated">
-      <a href="#" i18n:translate=""
-         tal:attributes="href python: view.url(layout.site, '@@contactadmin')">
-          Contact
-      </a>
-      </li>
-      <li tal:condition="layout/isAuthenticated">
-      <a href="#" i18n:translate=""
-         tal:attributes="href python: view.url(context, '@@logout')">
-         Logout
-      </a>
-      </li>
-    </ul>
-    <!-- Diazo element-->
-
-    <span tal:define="langs provider:languages"
-          tal:condition="langs"
-          class="language">
-      <tal:languages tal:content="structure langs" /> |
-    </span>
-
-    <!-- Diazo element-->
-    <ul class="breadcrumb" tal:condition="layout/isAuthenticated">
-      <tal:breadcrumbs
-            tal:condition="python: layout.isAuthenticated()"
-            tal:content="structure provider:breadcrumbs" />
-    </ul>
-    <!-- /Diazo element-->
-
-    <!-- Diazo element-->
-    <div class="ikoba-content">
-      <div class="actionbar" tal:condition="provider:actionbar">
-        <tal:actionbar content="structure provider:actionbar" />&nbsp;
-      </div>
-      <div tal:define="message context/@@messages"
-           tal:condition="python: len(message)>11">
-        <div tal:content="structure message">
-        </div>
-      </div>
-      <div class="alert alert-danger"
-        tal:define="status view/status|nothing"
-        tal:condition="status">
-        <span tal:content="view/status">
-          FORM STATUS SUMMARY
-        </span>:
-        <ul id="alert-error" tal:condition="view/errors">
-          <li tal:repeat="error view/error_views">
-             <span tal:replace="structure error">Error Type</span>
-          </li>
-        </ul>
-      </div>
-      <h1 class="ikoba-content-label"
-          tal:condition="view/label|nothing"
-          tal:content="structure view/label">Label</h1>
-      <div tal:content="structure view/content">
-        THE CONTENT
-      </div>
-      <br />
-    </div>
-    <!-- /Diazo element-->
-
-  </body>
-  <!-- /Diazo element-->
-
-</html>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/universitypage.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/universitypage.pt	(revision 11951)
+++ 	(revision )
@@ -1,1 +1,0 @@
-<span tal:replace="structure view/frontpage">Frontpage</span>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/universityrss20feed.pt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/templates/universityrss20feed.pt	(revision 11951)
+++ 	(revision )
@@ -1,59 +1,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<rss version="2.0"
-     xmlns:tal="http://xml.zope.org/namespaces/tal"
-     xmlns:atom="http://www.w3.org/2005/Atom">
-  <channel>
-    <title>
-      <tal:block tal:content="view/title"/>
-      <tal:block
-	  tal:define="title view/contexttitle"
-	  tal:condition="title"> - <tal:block content="title"/>
-      </tal:block>
-    </title>
-    <link
-	tal:content="view/link"></link>
-    <description
-	tal:content="view/description"></description>
-    <language
-	tal:condition="view/language"
-	tal:content="view/language"></language>
-    <pubDate
-	tal:condition="view/date"
-	tal:content="view/date"></pubDate>
-    <lastBuildDate
-	tal:condition="view/buildDate"
-	tal:content="view/buildDate"></lastBuildDate>
-    <managingEditor
-	tal:condition="view/editor"
-	tal:content="view/editor"></managingEditor>
-    <webMaster
-	tal:condition="view/webmaster"
-	tal:content="view/webmaster"></webMaster>
-    <atom:link
-	tal:attributes="href string:${view/link}@@feeds/${view/name}"
-	rel="self" type="application/rss+xml" />
-    <item
-	tal:repeat="item view/entries">
-      <title
-	  tal:content="item/title"></title>
-      <description
-	  tal:content="item/description"></description>
-      <guid
-	  tal:content="item/guid"
-	  tal:define="isPermaLink item/isPermaLink|nothing"
-	  tal:attributes="isPermaLink python:isPermaLink and 'true' or 'false'"></guid>
-      <link
-	  tal:condition="item/link|nothing"
-	  tal:content="item/link"></link>
-      <author
-	  tal:condition="item/author|nothing"
-	  tal:content="item/author"></author>
-      <category
-	  tal:condition="item/category|nothing"
-	  tal:content="item/category"></category>
-      <pubDate
-	  tal:condition="item/pubDate|nothing"
-	  tal:content="item/pubDate"></pubDate>
-    </item>
-  </channel>
-</rss>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_async.py	(revision 11952)
@@ -8,5 +8,5 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.async import AsyncJob, get_job_id
 from waeup.ikoba.interfaces import IJobManager
@@ -29,5 +29,5 @@
         self.storage = os.path.join(self.workdir, 'storage')
         os.mkdir(self.storage)
-        app = University()
+        app = Institution()
         app['datacenter'].setStoragePath(self.storage)
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/viewlets.py	(revision 11952)
@@ -24,8 +24,8 @@
 from zope.traversing.browser import absoluteURL
 from waeup.ikoba.browser.pages import (
-    UniversityPage, DatacenterPage,
+    InstitutionPage, DatacenterPage,
     UsersContainerPage, UserManageFormPage)
 from waeup.ikoba.browser.interfaces import (
-    IBreadcrumbContainer, IUniversity, IUsersContainer)
+    IBreadcrumbContainer, IInstitution, IUsersContainer)
 from waeup.ikoba.interfaces import (
     IIkobaUtils, IIkobaObject, IIkobaXMLExporter,
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/frontpage.html	(revision 11952)
@@ -2,6 +2,5 @@
 <br>
 <p class="ikoba-content-desc">
-the Information and Registration Portal
-for Schools, Colleges and Universities
+the Online Application and Registration Portal
 </p>
 </h1>
@@ -55,5 +54,5 @@
 <br>
 <small>
-dem Informations- und Registrierungs-Portal für Schulen und Universitäten
+dem Anmelde- und Registrierungs-Portal
 </small>
 </h1>
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/imagestorage.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/imagestorage.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/imagestorage.py	(revision 11952)
@@ -285,5 +285,5 @@
     want to change this path -- it is dynamic. That means, if you call
     the file store from 'within' a site, the root path will be located
-    inside this site (a :class:`waeup.ikoba.University` instance). If
+    inside this site (a :class:`waeup.ikoba.Institution` instance). If
     you call it from 'outside' a site some temporary dir (always the
     same during lifetime of the file store instance) will be used. The
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/index.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/index.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/index.txt	(revision 11952)
@@ -20,5 +20,5 @@
    accesscodes/api.txt
    jambtables/api.txt
-   university/api.txt
+   institution/api.txt
    utils/api.txt
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/de/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/de/LC_MESSAGES/waeup.ikoba.po	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/de/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
@@ -1073,13 +1073,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr "Name der Universität"
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr "Deomo-Universität"
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr "Abkürzung"
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/en/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/en/LC_MESSAGES/waeup.ikoba.po	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/en/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
@@ -1004,13 +1004,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/fr/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/fr/LC_MESSAGES/waeup.ikoba.po	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/fr/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
@@ -1076,13 +1076,13 @@
 #: waeup/ikoba/interfaces.py:595
 #, fuzzy
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr "Nom du département"
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ha/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ha/LC_MESSAGES/waeup.ikoba.po	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ha/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
@@ -1005,13 +1005,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ig/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ig/LC_MESSAGES/waeup.ikoba.po	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/ig/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
@@ -1005,13 +1005,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/waeup.ikoba.pot
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/waeup.ikoba.pot	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/waeup.ikoba.pot	(revision 11952)
@@ -1011,13 +1011,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/yo/LC_MESSAGES/waeup.ikoba.po
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/yo/LC_MESSAGES/waeup.ikoba.po	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/locales/yo/LC_MESSAGES/waeup.ikoba.po	(revision 11952)
@@ -1005,13 +1005,13 @@
 
 #: waeup/ikoba/interfaces.py:595
-msgid "Name of University"
+msgid "Name of Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:596
-msgid "Sample University"
+msgid "Sample Institution"
 msgstr ""
 
 #: waeup/ikoba/interfaces.py:601
-msgid "Abbreviated Title of University"
+msgid "Abbreviated Title of Institution"
 msgstr ""
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/browser.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/browser.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/browser.py	(revision 11952)
@@ -20,5 +20,5 @@
 import grok
 from waeup.ikoba.browser.layout import UtilityView
-from waeup.ikoba.interfaces import IUniversity
+from waeup.ikoba.interfaces import IInstitution
 from waeup.ikoba.interfaces import MessageFactory as _
 
@@ -26,5 +26,5 @@
     """View to execute mandate.
     """
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.name('mandate')
     grok.require('waeup.Public')
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/container.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/container.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/container.py	(revision 11952)
@@ -49,5 +49,5 @@
 
 class MandatesPlugin(grok.GlobalUtility):
-    """A plugin that creates container for mandates inside a university.
+    """A plugin that creates container for mandates inside a institution.
     """
     grok.implements(IIkobaPluggable)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/tests.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/tests.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/mandates/tests.py	(revision 11952)
@@ -27,5 +27,5 @@
 from zope.component import createObject
 from zope.component.hooks import setSite, clearSite
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.interfaces import IUserAccount
 from waeup.ikoba.mandates.interfaces import (
@@ -63,5 +63,5 @@
 
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py	(revision 11952)
@@ -19,5 +19,5 @@
 """
 import grok
-from waeup.ikoba.interfaces import IUniversity
+from waeup.ikoba.interfaces import IInstitution
 from waeup.ikoba.payments.interfaces import IPayment
 
@@ -25,5 +25,5 @@
     """A catalog for all payments.
     """
-    grok.site(IUniversity)
+    grok.site(IInstitution)
     grok.name('payments_catalog')
     grok.context(IPayment)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/testing.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/testing.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/testing.py	(revision 11952)
@@ -126,5 +126,5 @@
         maybe_grok, setUpZope, cleanUpZope,
         )
-      from waeup.ikoba.app import University
+      from waeup.ikoba.app import Institution
 
       class MyTestCase(unittest.TestCase):
@@ -148,5 +148,5 @@
 
           def test_jambdata_in_site(self):
-              u = University()
+              u = Institution()
               self.assertTrue('jambdata' in u.keys())
               return
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_app.py	(revision 11952)
@@ -22,29 +22,29 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.interfaces import (
-    IUniversity, IJobManager, VIRT_JOBS_CONTAINER_NAME)
+    IInstitution, IJobManager, VIRT_JOBS_CONTAINER_NAME)
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
-class UniversityTests(FunctionalTestCase):
+class InstitutionTests(FunctionalTestCase):
 
     layer = FunctionalLayer
 
     def setUp(self):
-        super(UniversityTests, self).setUp()
+        super(InstitutionTests, self).setUp()
         self.workdir = tempfile.mkdtemp()
-        self.getRootFolder()['app'] = University()
+        self.getRootFolder()['app'] = Institution()
         self.app = self.getRootFolder()['app']
         return
 
     def tearDown(self):
-        super(UniversityTests, self).tearDown()
+        super(InstitutionTests, self).tearDown()
         shutil.rmtree(self.workdir)
         return
 
     def test_ifaces(self):
-        university = University()
-        assert verifyClass(IUniversity, University)
-        assert verifyObject(IUniversity, university)
+        institution = Institution()
+        assert verifyClass(IInstitution, Institution)
+        assert verifyObject(IInstitution, institution)
         return
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_imagestorage.py	(revision 11952)
@@ -27,5 +27,5 @@
 from zope.component.hooks import setSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 from waeup.ikoba.imagestorage import (
@@ -228,5 +228,5 @@
         self.fd = open(self.samplefile, 'r')
         self.fd2 = open(self.otherfile, 'r')
-        self.getRootFolder()['app'] = University()
+        self.getRootFolder()['app'] = Institution()
         self.app = self.getRootFolder()['app']
         self.app['datacenter'].setStoragePath(self.workdir)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_maintenance.py	(revision 11952)
@@ -9,5 +9,5 @@
 from zope.component.hooks import setSite
 from zope.interface import Interface, implements
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.maintenance import update_catalog
 from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
@@ -41,5 +41,5 @@
         super(UpdateCatalogTests, self).setUp()
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_objecthistory.py	(revision 11952)
@@ -25,5 +25,5 @@
 from zope.security.management import newInteraction, endInteraction
 from zope.security.testing import Principal, Participation
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.interfaces import IObjectHistory, IIkobaObject
 from waeup.ikoba.testing import FunctionalTestCase, FunctionalLayer
@@ -43,5 +43,5 @@
 
         # Prepopulate ZODB
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/tests/test_smtp.py	(revision 11952)
@@ -27,5 +27,5 @@
 from zope.component.hooks import setSite
 from zope.sendmail.interfaces import IMailDelivery
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.interfaces import IMailService
 from waeup.ikoba.smtp import (
@@ -341,5 +341,5 @@
         super(ExternalMailerTests, self).setUp()
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.py	(revision 11952)
@@ -92,5 +92,5 @@
                     obj= object
                     path = ''
-                    while obj.__class__.__name__ != 'University':
+                    while obj.__class__.__name__ != 'Institution':
                         path = '%s/' % obj.__name__ + path
                         obj = obj.__parent__
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/userscontainer.txt	(revision 11952)
@@ -1,4 +1,4 @@
 User container for the Ikoba
-***************************
+****************************
 
 .. :doctest:
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/batching.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/batching.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/batching.txt	(revision 11952)
@@ -20,5 +20,5 @@
 * accepts a single data type identified by an interface.
 
-* knows about the places inside a site (University) where to store,
+* knows about the places inside a site (Institution) where to store,
   remove or update the data.
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/browser.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/browser.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/browser.py	(revision 11952)
@@ -25,5 +25,5 @@
 from waeup.ikoba.interfaces import IObjectHistory
 
-from waeup.ikoba.interfaces import IUniversity
+from waeup.ikoba.interfaces import IInstitution
 
 class ReindexPage(UtilityView, grok.View):
@@ -32,5 +32,5 @@
     Reindexes a catalog. For managers only.
     """
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.name('reindex')
     grok.require('waeup.managePortal')
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/helpers.txt
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/helpers.txt	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/helpers.txt	(revision 11952)
@@ -185,5 +185,5 @@
      ... <BLANKLINE>
      ... <body>
-     ... <form action="http://localhost/myuniversity/faculties/TF/add"
+     ... <form action="http://localhost/myinstitution/faculties/TF/add"
      ...       method="post" class="edit-form"
      ...       enctype="multipart/form-data">
@@ -194,5 +194,5 @@
      ... """)
      <BLANKLINE>
-     <form action="http://localhost/myuniversity/faculties/TF/add"
+     <form action="http://localhost/myinstitution/faculties/TF/add"
            method="post" class="edit-form"
            enctype="multipart/form-data">
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/logger.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/logger.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/logger.py	(revision 11952)
@@ -67,7 +67,7 @@
 
 The datacenter and its storage are created automatically when you
-create a :class:`waeup.ikoba.app.University`. This also means that
+create a :class:`waeup.ikoba.app.Institution`. This also means that
 logging with the `Logger` mix-in will work only inside so-called sites
-(`University` instances put into ZODB are such `sites`).
+(`Institution` instances put into ZODB are such `sites`).
 
 Other components in this module help to make everything work.
@@ -386,6 +386,6 @@
     return
 
-from waeup.ikoba.interfaces import IUniversity
-@grok.subscribe(IUniversity, grok.IObjectRemovedEvent)
+from waeup.ikoba.interfaces import IInstitution
+@grok.subscribe(IInstitution, grok.IObjectRemovedEvent)
 def handle_site_removed(obj, event):
     collector = queryUtility(ILoggerCollector)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_batching.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_batching.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_batching.py	(revision 11952)
@@ -30,5 +30,5 @@
 from zope.component.interfaces import IFactory
 from zope.interface import Interface, implements, verify
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.interfaces import (
     ICSVExporter, IBatchProcessor, IExportJobContainer, IJobManager,
@@ -137,5 +137,5 @@
 
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
@@ -597,5 +597,5 @@
     def test_active_site(self):
         # we get the datafinder if one is installed and site set
-        self.getRootFolder()['app'] = University()
+        self.getRootFolder()['app'] = Institution()
         finder = getUtility(IExportContainerFinder)
         setSite(self.getRootFolder()['app'])
@@ -606,5 +606,5 @@
     def test_broken_site(self):
         # if the current site has no ExportContainer, we get None
-        self.getRootFolder()['app'] = University()
+        self.getRootFolder()['app'] = Institution()
         app = self.getRootFolder()['app']
         del app['datacenter'] # datacenter _is_ the export container
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_converters.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_converters.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_converters.py	(revision 11952)
@@ -32,5 +32,5 @@
     Interface, implements, invariant, Invalid, implementedBy, verify)
 
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 from waeup.ikoba.interfaces import (
@@ -155,5 +155,5 @@
 
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_logger.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_logger.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/tests/test_logger.py	(revision 11952)
@@ -25,5 +25,5 @@
 from zope.component.hooks import setSite, clearSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.testing import FunctionalLayer, FunctionalTestCase
 
@@ -49,5 +49,5 @@
         super(LoggersTests, self).setUp()
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         self.dc_root2 = None
@@ -223,5 +223,5 @@
 
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
@@ -281,5 +281,5 @@
         super(LoggerCollectorTests, self).setUp()
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         app['datacenter'].setStoragePath(self.dc_root)
@@ -377,5 +377,5 @@
         super(LogfileChangeTests, self).setUp()
         # Setup a sample site for each test
-        app = University()
+        app = Institution()
         self.dc_root = tempfile.mkdtemp()
         self.dc_root_new = None
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/utils.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/utils.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/utils/utils.py	(revision 11952)
@@ -136,8 +136,4 @@
         }
 
-    DISABLE_PAYMENT_GROUP_DICT = {
-        'sf_all': 'School Fee - All Students',
-        }
-
     APP_CATS_DICT = {
         'basic': 'Basic Application',
@@ -267,5 +263,5 @@
 
 ${b}
-Student Registration and Information Portal of
+Application and Registration Portal of
 ${c}.
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/webservices.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/webservices.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/webservices.py	(revision 11952)
@@ -20,5 +20,5 @@
 from zope.component import getUtility
 from zope.catalog.interfaces import ICatalog
-from waeup.ikoba.interfaces import IUniversity, application_sessions_vocab
+from waeup.ikoba.interfaces import IInstitution, application_sessions_vocab
 
 class XMLRPCPermission(grok.Permission):
@@ -34,5 +34,5 @@
     grok.permissions('waeup.xmlrpc',)
 
-class UniversityXMLRPC(grok.XMLRPC):
+class InstitutionXMLRPC(grok.XMLRPC):
     """XMLRPC webservices for Ikoba portals.
 
@@ -40,5 +40,5 @@
     but positional arguments only.
     """
-    grok.context(IUniversity)
+    grok.context(IInstitution)
 
     @grok.require('waeup.Public')

Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/app.py	(revision 11952)
@@ -25,5 +25,5 @@
 from waeup.ikoba.mandates.container import MandatesContainer
 from waeup.ikoba.interfaces import (
-    IUniversity, IIkobaPluggable, IObjectUpgradeEvent, IJobManager,
+    IInstitution, IIkobaPluggable, IObjectUpgradeEvent, IJobManager,
     VIRT_JOBS_CONTAINER_NAME)
 from waeup.ikoba.userscontainer import UsersContainer
@@ -32,8 +32,8 @@
 from waeup.ikoba.configuration import ConfigurationContainer
 
-class University(grok.Application, grok.Container, Logger):
-    """A university.
+class Institution(grok.Application, grok.Container, Logger):
+    """A institution.
     """
-    grok.implements(IUniversity)
+    grok.implements(IInstitution)
 
     # Setup authentication for this app. Note: this is only
@@ -44,5 +44,5 @@
 
     def __init__(self, *args, **kw):
-        super(University, self).__init__(*args, **kw)
+        super(Institution, self).__init__(*args, **kw)
         self.setup()
         return
@@ -85,5 +85,5 @@
         self.logger.info('Plugin update finished.')
         return
-attrs_to_fields(University)
+attrs_to_fields(Institution)
 
 class ObjectUpgradeEvent(ObjectEvent):
@@ -92,8 +92,8 @@
     grok.implements(IObjectUpgradeEvent)
 
-@grok.subscribe(University, grok.IObjectAddedEvent)
-def handle_university_added(app, event):
-    """If a university is added, a message is logged.
+@grok.subscribe(Institution, grok.IObjectAddedEvent)
+def handle_institution_added(app, event):
+    """If a institution is added, a message is logged.
     """
-    app.logger.info('University `%s` added.' % getattr(app, '__name__', None))
+    app.logger.info('Institution `%s` added.' % getattr(app, '__name__', None))
     return
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/breadcrumbs.py	(revision 11952)
@@ -28,5 +28,5 @@
 from waeup.ikoba.browser.interfaces import (
     IBreadcrumb, IBreadcrumbIgnorable, IBreadcrumbContainer, IIkobaObject,
-    IUniversity, IUsersContainer, IDataCenter,
+    IInstitution, IUsersContainer, IDataCenter,
     )
 from waeup.ikoba.reports import IReportsContainer
@@ -86,8 +86,8 @@
         return self.viewname
 
-class UniversityBreadcrumb(Breadcrumb):
-    """A breadcrumb for university index pages.
-    """
-    grok.context(IUniversity)
+class InstitutionBreadcrumb(Breadcrumb):
+    """A breadcrumb for institution index pages.
+    """
+    grok.context(IInstitution)
     title = _(u'Home')
     parent = None
@@ -97,10 +97,10 @@
 
     Here we need a special `parent()` implementation, because the
     parent object is not a real parent (the University object has no
     valid parent in terms of breadcrumbs). Instead it is the
     ``administration`` view of the same context the ``manage`` page
     itself is bound to.
     """
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.name('manage')
     title = _(u'Portal Settings')
@@ -113,7 +113,7 @@
 
 class AdministrationBreadcrumb(Breadcrumb):
-    """A breadcrumb for administration areas of University instances.
-    """
-    grok.context(IUniversity)
+    """A breadcrumb for administration areas of Institution instances.
+    """
+    grok.context(IInstitution)
     grok.name('administration')
     title = _(u'Administration')
@@ -158,11 +158,4 @@
     title = _(u'Reports')
     parent_viewname = 'administration'
-    target = None
-
-class ExportsBreadcrumb(Breadcrumb):
-    """A breadcrumb for exports.
-    """
-    grok.context(IExportJobContainer)
-    title = _(u'Student Data Exports')
     target = None
 
@@ -97,10 +97,10 @@
 
     Here we need a special `parent()` implementation, because the
-    parent object is not a real parent (the University object has no
+    parent object is not a real parent (the Institution object has no
     valid parent in terms of breadcrumbs). Instead it is the
     ``administration`` view of the same context the ``manage`` page
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/pages.py	(revision 11952)
@@ -46,5 +46,5 @@
     IkobaDisplayFormPage, NullValidator)
 from waeup.ikoba.browser.interfaces import (
-    IUniversity, ICaptchaManager, IChangePassword)
+    IInstitution, ICaptchaManager, IChangePassword)
 from waeup.ikoba.browser.layout import jsaction, action, UtilityView
 from waeup.ikoba.interfaces import MessageFactory as _
@@ -268,8 +268,8 @@
                 self.flash(_('You logged in.'))
                 if self.request.principal.user_type == 'customer':
-                    student = grok.getSite()['customerss'][
+                    customer = grok.getSite()['customers'][
                         self.request.principal.id]
                     rel_link = '/customers/%s' % self.request.principal.id
-                    if student.personal_data_expired:
+                    if customer.personal_data_expired:
                         rel_link = '/customerss/%s/edit_personal' % (
                             self.request.principal.id)
@@ -325,5 +325,5 @@
 class ContactAdminForm(IkobaForm):
     grok.name('contactadmin')
-    #grok.context(IUniversity)
+    #grok.context(IInstitution)
     grok.template('contactform')
     grok.require('waeup.Authenticated')
@@ -405,13 +405,13 @@
 
 #
 # University related pages...
 #
 
-class UniversityPage(IkobaDisplayFormPage):
-    """ The main university page.
+class InstitutionPage(IkobaDisplayFormPage):
+    """ The main institution page.
     """
     grok.require('waeup.Public')
     grok.name('index')
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     pnav = 0
     label = ''
@@ -434,5 +434,5 @@
     """
     grok.name('administration')
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.require('waeup.managePortal')
     label = _(u'Administration')
@@ -443,7 +443,7 @@
     """
     grok.name('feed.rss')
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.require('waeup.Public')
-    grok.template('universityrss20feed')
+    grok.template('institutionrss20feed')
 
     name = 'General news feed'
@@ -457,5 +457,5 @@
     @property
     def title(self):
-        return getattr(grok.getSite(), 'name', u'Sample University')
+        return getattr(grok.getSite(), 'name', u'Sample Institution')
 
     @property
@@ -1568,5 +1568,5 @@
     """Captcha'd page for all kind of users to request a password change.
     """
-    grok.context(IUniversity)
+    grok.context(IInstitution)
     grok.name('changepw')
     grok.require('waeup.Anonymous')
@@ -1589,5 +1589,5 @@
         #    email=(email,email))
         #for result in results:
-        #    if result.student_id == identifier or \
+        #    if result.customer_id == identifier or \
         #        result.reg_number == identifier or \
         #        result.matric_number == identifier:
@@ -405,13 +405,13 @@
 
 #
-# University related pages...
+# Institution related pages...
 #
 
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/browser/tests/test_permissions.py	(revision 11952)
@@ -31,5 +31,5 @@
 from zope.security.interfaces import Unauthorized
 from zope.testbrowser.testing import Browser
-from waeup.ikoba.app import University
+from waeup.ikoba.app import Institution
 from waeup.ikoba.testing import (
     FunctionalLayer, FunctionalTestCase, get_all_loggers, remove_new_loggers,
@@ -58,6 +58,6 @@
     def setUp(self):
         super(PermissionTest, self).setUp()
-        # Set up a complete university to have every page available...
-        app = University()
+        # Set up a complete institution to have every page available...
+        app = Institution()
         self.getRootFolder()['app'] = app
         setSite(self.getRootFolder()['app'])
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/interfaces.py	(revision 11951)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/interfaces.py	(revision 11952)
@@ -288,6 +288,6 @@
     """
 
-class IUniversity(IIkobaObject):
-    """Representation of a university.
+class IInstitution(IIkobaObject):
+    """Representation of an institution.
     """
 
@@ -593,11 +593,11 @@
 
     name = schema.TextLine(
-        title = _(u'Name of University'),
-        default = _(u'Sample University'),
+        title = _(u'Name of Institution'),
+        default = _(u'Sample Institution'),
         required = True,
         )
 
     acronym = schema.TextLine(
-        title = _(u'Abbreviated Title of University'),
+        title = _(u'Abbreviated Title of Institution'),
         default = u'WAeUP.Ikoba',
         required = True,
@@ -796,8 +796,8 @@
     Components implementing this interface are referred to as
     'plugins'. They are normally called when a new
-    :class:`waeup.ikoba.app.University` instance is created.
+    :class:`waeup.ikoba.app.Institution` instance is created.
 
     Plugins can setup and update parts of the central site without the
-    site object (normally a :class:`waeup.ikoba.app.University` object)
+    site object (normally a :class:`waeup.ikoba.app.Institution` object)
     needing to know about that parts. The site simply collects all
     available plugins, calls them and the plugins care for their
@@ -852,5 +852,5 @@
     Utilities providing this interface are looked up when a Pluggable
     Authentication Utility (PAU) for any
-    :class:`waeup.ikoba.app.University` instance is created and put
+    :class:`waeup.ikoba.app.Institution` instance is created and put
     into ZODB.
 